@@ -447,11 +447,8 @@ fs_end_frame (GnomeScanPlugin *plugin)
 				       sink->count+1,
 				       sink->suffix);
 
-#define dbg_ref(t,o)	g_debug("%s:%i %s %s:%i",__FUNCTION__,__LINE__,t,G_OBJECT_TYPE_NAME(o),G_OBJECT(o)->ref_count);
-#define destroy(t,o)	dbg_ref(t,o); g_object_unref(o); o = NULL;
-    destroy ("output", priv->output);
+    g_object_unref(priv->output);
     /* needs to unref one more time. Maybe a bug in GeglOp buffer ? */
-#undef destroy
     break;
 #ifdef	PRINT
   case FLEGITA_PRINT:
